# pixcat

[![PyPI downloads](http://pepy.tech/badge/pixcat)](
    http://pepy.tech/project/pixcat)
[![PyPI version](https://img.shields.io/pypi/v/pixcat.svg)](
    https://pypi.org/projects/pixcat)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/pixcat.svg)](
    https://pypi.python.org/pypi/pixcat)

**WORK IN PROGRESS**

Display images on a [kitty](https://sw.kovidgoyal.net/kitty/) terminal
with optional custom/thumbnail/fit-to-screen resizing.  
Developed with the goal of being a more powerful alternative to `kitty icat`,
while also providing an usable Python 3.6+ API.

## Usage

CLI:

```sh
    pixcat --help
```

Python library (no documentation yet):

```python3
    import pixcat
    ...
```

## Installation

Requires Python 3.6+, tested on GNU/Linux only.

```sh
    pip3 install --upgrade pixcat
```
